==> enterprisemodules-ora_config-3.9.9.tar.gz: enterprisemodules-ora_config-3.9.9/lib/puppet/provider/ora_exec/sqlplus.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/access'
require 'easy_type/helpers'
require 'puppet_x/enterprisemodules/oracle/ora_tab'
require 'fileutils'

Puppet::Type.type(:ora_exec).provide(:sqlplus) do
  include Puppet_X::EnterpriseModules::Oracle::Access
  include EasyType::Helpers
  include EasyType::Template

  confine :exists => settings_file

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'
    execute
  end

  def onlyif?
    return true if resource[:onlyif].nil?
    value = execute_query(resource[:onlyif])
    message = value ? \
      "#{resource.path}: onlyif query returned record. So statement is executed." : \
      "#{resource.path}: onlyif query returned no records. So statement is not executed."
    Puppet.debug message
    value
  end

  def unless?
    return false if resource[:unless].nil?
    value = execute_query(resource[:unless])
    message = value ?
      "#{resource.path}: unless query returned records. So statement is not executed." : \
      "#{resource.path}: unless query returned no records. So statement is executed."
    Puppet.debug message
    !value
  end

  #
  # Determine based on the values of unless and onlyif, if we 
  # need to execute the main statement.
  #
  def need_to_execute?
    @unless_value = unless? if @unless_value.nil?
    @onlyif_value = onlyif? if @onlyif_value.nil?
    case
    when resource.onlyif_specified? && !resource.unless_specified?
      @onlyif_value
    when !resource.onlyif_specified? && resource.unless_specified?
      @unless_value
    when resource.onlyif_specified? && resource.unless_specified?
      (@unless_value || @onlyif_value)
    else
      true
    end
  end

  def execute_query(query)
    sid = sid_from_resource
    options = { :sid => sid }
    options[:username] = resource[:username] if resource[:username]
    options[:password] = resource[:password] if resource[:password]
    rows = sql query, options
    rows.any?
  end

  def execute
    cwd           = resource[:cwd]
    statement     = resource[:statement]
    sid           = sid_from_resource
    options       = { :sid => sid, :parse => false }
    options[:catch_errors] = resource.mark_as_error unless resource.mark_as_error.nil?
    options[:failonsqlfail] = resource.report_errors?
    options[:username] = resource.username unless resource.username.nil?
    options[:password] = resource.password unless resource.password.nil?

    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)
    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    output = sql statement, options
    Puppet.debug(output) if resource.logoutput.to_s == 'true'
  end

  private

  def is_script?(statement)
    statement[0] == 64
  end
end

==> enterprisemodules-ora_config-3.18.0.tar.gz: enterprisemodules-ora_config-3.18.0/lib/puppet/provider/ora_exec/sqlplus.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/access'
require 'easy_type/helpers'
require 'puppet_x/enterprisemodules/oracle/ora_tab'
require 'fileutils'

Puppet::Type.type(:ora_exec).provide(:sqlplus) do
  include Puppet_X::EnterpriseModules::Oracle::Access
  include EasyType::Helpers
  include EasyType::Template

  confine :exists => settings_file

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'
    execute
  end

  def onlyif?
    return true if resource[:onlyif].nil?
    value = execute_query(resource[:onlyif])
    message = value ? \
      "#{resource.path}: onlyif query returned record. So statement is executed." : \
      "#{resource.path}: onlyif query returned no records. So statement is not executed."
    Puppet.debug message
    value
  end

  def unless?
    return false if resource[:unless].nil?
    value = execute_query(resource[:unless])
    message = value ?
      "#{resource.path}: unless query returned records. So statement is not executed." : \
      "#{resource.path}: unless query returned no records. So statement is executed."
    Puppet.debug message
    !value
  end

  #
  # Determine based on the values of unless and onlyif, if we 
  # need to execute the main statement.
  #
  def need_to_execute?
    @unless_value = unless? if @unless_value.nil?
    @onlyif_value = onlyif? if @onlyif_value.nil?
    case
    when resource.onlyif_specified? && !resource.unless_specified?
      @onlyif_value
    when !resource.onlyif_specified? && resource.unless_specified?
      @unless_value
    when resource.onlyif_specified? && resource.unless_specified?
      (@unless_value || @onlyif_value)
    else
      true
    end
  end

  def execute_query(query)
    sid = sid_from_resource
    options = { :sid => sid }
    options[:username] = resource[:username] if resource[:username]
    options[:password] = resource[:password] if resource[:password]
    rows = safe_sql query, options
    rows.any?
  end

  def execute
    cwd           = resource[:cwd]
    statement     = resource[:statement]
    sid           = sid_from_resource
    options       = { :sid => sid, :parse => false }
    options[:catch_errors] = resource.mark_as_error unless resource.mark_as_error.nil?
    options[:failonsqlfail] = resource.report_errors?
    options[:username] = resource.username unless resource.username.nil?
    options[:password] = resource.password unless resource.password.nil?

    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)
    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    output = safe_sql statement, options
    Puppet.debug(output) if resource.logoutput.to_s == 'true'
  end

  private

  def is_script?(statement)
    statement[0] == 64
  end
end
